/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include <cassert>
#include <cmath>

#include <vector>
#include <algorithm>
#include <fstream>
#include <iostream>

#define C10 2.2E+07
#define C20 100.
#define C30 30.

#define EMIN 0.1 // MeV
#define EMAX 2470. // MeV

#define NOF_BINS 2000

namespace {

std::vector<double>
equal_distant_points( double lower, double upper, unsigned int points)
{
	assert(points > 1);
	assert(upper > lower);

	std::vector<double> data(points + 1);

	double step = (upper - lower) / points;
	double value = lower;
	for ( unsigned int i = 0; i < points + 1; ++i, value += step)
		data[i] = value;

	return data;
}

double
exp_fluence(double energy)
{
	return C10*exp(-(energy-C20)/C30);
}

} // namespace

int
main( int argc, char** argv)
{
	std::vector<double> val;
	std::vector<double> res;
	val = equal_distant_points( EMIN, EMAX, NOF_BINS);

	res.resize(val.size());
	std::transform( val.begin(), val.end(), res.begin(), exp_fluence);

	std::ofstream test;
	test.open( "flu.dat", std::ofstream::out);

	test << std::scientific;
	for ( size_t i = 0; i < val.size(); ++i) {
		test << val[i] << " " << res[i] << std::endl;
	}
	test.close();
 
	return 0;
}
